package cn.com.infosec.jce.provider;

import cn.com.infosec.asn1.ASN1InputStream;
import cn.com.infosec.asn1.ASN1Sequence;
import cn.com.infosec.asn1.ASN1Set;
import cn.com.infosec.asn1.ASN1TaggedObject;
import cn.com.infosec.asn1.DEREncodable;
import cn.com.infosec.asn1.DERObjectIdentifier;
import cn.com.infosec.asn1.pkcs.PKCSObjectIdentifiers;
import cn.com.infosec.asn1.pkcs.SignedData;
import cn.com.infosec.asn1.x509.CertificateList;
import cn.com.infosec.asn1.x509.X509CertificateStructure;
import java.io.InputStream;
import java.io.PushbackInputStream;
import java.security.cert.CRL;
import java.security.cert.CRLException;
import java.security.cert.CertPath;
import java.security.cert.Certificate;
import java.security.cert.CertificateException;
import java.security.cert.CertificateFactorySpi;
import java.security.cert.X509Certificate;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Iterator;
import java.util.List;

public class JDKX509CertificateFactoryFX extends CertificateFactorySpi {
   private static final PEMUtil PEM_CERT_PARSER = new PEMUtil("CERTIFICATE");
   private static final PEMUtil PEM_CRL_PARSER = new PEMUtil("CRL");
   private ASN1Set sData = null;
   private int sDataObjectCount = 0;
   private InputStream currentStream = null;
   private ASN1Set sCrlData = null;
   private int sCrlDataObjectCount = 0;
   private InputStream currentCrlStream = null;

   private Certificate readDERCertificate(ASN1InputStream dIn) {
      ASN1Sequence dIn1;
      if ((dIn1 = (ASN1Sequence)dIn.readObject()).size() > 1 && dIn1.getObjectAt(0) instanceof DERObjectIdentifier && dIn1.getObjectAt(0).equals(PKCSObjectIdentifiers.signedData)) {
         this.sData = (new SignedData(ASN1Sequence.getInstance((ASN1TaggedObject)dIn1.getObjectAt(1), true))).getCertificates();
         return this.getCertificate();
      } else {
         return new X509CertificateObject(X509CertificateStructure.getInstance(dIn1));
      }
   }

   private Certificate getCertificate() {
      if (this.sData != null) {
         while(this.sDataObjectCount < this.sData.size()) {
            ASN1Set var10000 = this.sData;
            int var1;
            this.sDataObjectCount = (var1 = this.sDataObjectCount) + 1;
            DEREncodable var2;
            if ((var2 = var10000.getObjectAt(var1)) instanceof ASN1Sequence) {
               return new X509CertificateObject(X509CertificateStructure.getInstance(var2));
            }
         }
      }

      return null;
   }

   private Certificate readPEMCertificate(InputStream in) {
      ASN1Sequence var2;
      return (var2 = PEM_CERT_PARSER.readPEMObject(in)) != null ? new X509CertificateObject(X509CertificateStructure.getInstance(var2)) : null;
   }

   private CRL readPEMCRL(InputStream in) {
      ASN1Sequence in1;
      return (in1 = PEM_CRL_PARSER.readPEMObject(in)) != null ? this.createCRL(CertificateList.getInstance(in1)) : null;
   }

   private CRL readDERCRL(ASN1InputStream aIn) {
      ASN1Sequence aIn1;
      if ((aIn1 = (ASN1Sequence)aIn.readObject()).size() > 1 && aIn1.getObjectAt(0) instanceof DERObjectIdentifier && aIn1.getObjectAt(0).equals(PKCSObjectIdentifiers.signedData)) {
         this.sCrlData = (new SignedData(ASN1Sequence.getInstance((ASN1TaggedObject)aIn1.getObjectAt(1), true))).getCRLs();
         return this.getCRL();
      } else {
         return this.createCRL(CertificateList.getInstance(aIn1));
      }
   }

   private CRL getCRL() {
      ASN1Set var1;
      if ((var1 = this.sCrlData) != null && this.sCrlDataObjectCount < var1.size()) {
         JDKX509CertificateFactoryFX var10000 = this;
         ASN1Set var10001 = this.sCrlData;
         int var2;
         this.sCrlDataObjectCount = (var2 = this.sCrlDataObjectCount) + 1;
         return var10000.createCRL(CertificateList.getInstance(var10001.getObjectAt(var2)));
      } else {
         return null;
      }
   }

   protected CRL createCRL(CertificateList c) {
      return new X509CRLObject(c);
   }

   public Certificate engineGenerateCertificate(InputStream in) {
      InputStream var2;
      if ((var2 = this.currentStream) == null) {
         this.currentStream = in;
         this.sData = null;
         this.sDataObjectCount = 0;
      } else if (var2 != in) {
         this.currentStream = in;
         this.sData = null;
         this.sDataObjectCount = 0;
      }

      Exception var10000;
      label102: {
         boolean var10001;
         ASN1Set var20;
         try {
            var20 = this.sData;
         } catch (Exception var14) {
            var10000 = var14;
            var10001 = false;
            break label102;
         }

         ASN1Set var18 = var20;
         int var21;
         if (var20 != null) {
            label69: {
               int var22;
               try {
                  var21 = this.sDataObjectCount;
                  var22 = var18.size();
               } catch (Exception var5) {
                  var10000 = var5;
                  var10001 = false;
                  break label69;
               }

               if (var21 != var22) {
                  try {
                     return this.getCertificate();
                  } catch (Exception var3) {
                     var10000 = var3;
                     var10001 = false;
                  }
               } else {
                  try {
                     this.sData = null;
                     this.sDataObjectCount = 0;
                     return null;
                  } catch (Exception var4) {
                     var10000 = var4;
                     var10001 = false;
                  }
               }
            }
         } else {
            label106: {
               try {
                  ProviderUtil.getReadLimit(in);
               } catch (Exception var13) {
                  var10000 = var13;
                  var10001 = false;
                  break label106;
               }

               PushbackInputStream var23;
               try {
                  var23 = new PushbackInputStream;
               } catch (Exception var12) {
                  var10000 = var12;
                  var10001 = false;
                  break label106;
               }

               PushbackInputStream var19;
               PushbackInputStream var24 = var19 = var23;

               try {
                  var24.<init>(in);
                  var21 = var23.read();
               } catch (Exception var11) {
                  var10000 = var11;
                  var10001 = false;
                  break label106;
               }

               int in1 = var21;
               if (var21 == -1) {
                  return null;
               }

               try {
                  var21 = in1;
                  var19.unread(in1);
               } catch (Exception var10) {
                  var10000 = var10;
                  var10001 = false;
                  break label106;
               }

               if (var21 != 48) {
                  try {
                     return this.readPEMCertificate(var19);
                  } catch (Exception var6) {
                     var10000 = var6;
                     var10001 = false;
                  }
               } else {
                  label107: {
                     byte[] var25;
                     try {
                        var23 = var19;
                        var25 = new byte[var19.available()];
                     } catch (Exception var9) {
                        var10000 = var9;
                        var10001 = false;
                        break label107;
                     }

                     byte[] var15 = var25;

                     try {
                        var23.read(var25);
                     } catch (Exception var8) {
                        var10000 = var8;
                        var10001 = false;
                        break label107;
                     }

                     try {
                        return new X509CertificateObjectFX(var15);
                     } catch (Exception var7) {
                        var10000 = var7;
                        var10001 = false;
                     }
                  }
               }
            }
         }
      }

      Exception var16 = var10000;
      throw new CertificateException(var16.toString());
   }

   public Collection engineGenerateCertificates(InputStream inStream) {
      ArrayList var2;
      var2 = new ArrayList.<init>();

      Certificate var3;
      while((var3 = this.engineGenerateCertificate(inStream)) != null) {
         var2.add(var3);
      }

      return var2;
   }

   public CRL engineGenerateCRL(InputStream inStream) {
      InputStream var2;
      if ((var2 = this.currentCrlStream) == null) {
         this.currentCrlStream = inStream;
         this.sCrlData = null;
         this.sCrlDataObjectCount = 0;
      } else if (var2 != inStream) {
         this.currentCrlStream = inStream;
         this.sCrlData = null;
         this.sCrlDataObjectCount = 0;
      }

      Exception var10000;
      label130: {
         boolean var10001;
         CRLException var32;
         ASN1Set var33;
         try {
            var33 = this.sCrlData;
         } catch (CRLException var25) {
            var32 = var25;
            var10001 = false;
            throw var32;
         } catch (Exception var26) {
            var10000 = var26;
            var10001 = false;
            break label130;
         }

         ASN1Set var30 = var33;
         int var34;
         if (var33 != null) {
            label98: {
               int var35;
               try {
                  var34 = this.sCrlDataObjectCount;
                  var35 = var30.size();
               } catch (CRLException var7) {
                  var32 = var7;
                  var10001 = false;
                  throw var32;
               } catch (Exception var8) {
                  var10000 = var8;
                  var10001 = false;
                  break label98;
               }

               if (var34 != var35) {
                  try {
                     return this.getCRL();
                  } catch (CRLException var3) {
                     var32 = var3;
                     var10001 = false;
                     throw var32;
                  } catch (Exception var4) {
                     var10000 = var4;
                     var10001 = false;
                  }
               } else {
                  try {
                     this.sCrlData = null;
                     this.sCrlDataObjectCount = 0;
                     return null;
                  } catch (CRLException var5) {
                     var32 = var5;
                     var10001 = false;
                     throw var32;
                  } catch (Exception var6) {
                     var10000 = var6;
                     var10001 = false;
                  }
               }
            }
         } else {
            label137: {
               try {
                  ProviderUtil.getReadLimit(inStream);
               } catch (CRLException var23) {
                  var32 = var23;
                  var10001 = false;
                  throw var32;
               } catch (Exception var24) {
                  var10000 = var24;
                  var10001 = false;
                  break label137;
               }

               PushbackInputStream var36;
               try {
                  var36 = new PushbackInputStream;
               } catch (CRLException var21) {
                  var32 = var21;
                  var10001 = false;
                  throw var32;
               } catch (Exception var22) {
                  var10000 = var22;
                  var10001 = false;
                  break label137;
               }

               PushbackInputStream var31;
               PushbackInputStream var37 = var31 = var36;

               try {
                  var37.<init>(inStream);
                  var34 = var36.read();
               } catch (CRLException var19) {
                  var32 = var19;
                  var10001 = false;
                  throw var32;
               } catch (Exception var20) {
                  var10000 = var20;
                  var10001 = false;
                  break label137;
               }

               int inStream1 = var34;
               if (var34 == -1) {
                  return null;
               }

               try {
                  var34 = inStream1;
                  var31.unread(inStream1);
               } catch (CRLException var17) {
                  var32 = var17;
                  var10001 = false;
                  throw var32;
               } catch (Exception var18) {
                  var10000 = var18;
                  var10001 = false;
                  break label137;
               }

               if (var34 != 48) {
                  try {
                     return this.readPEMCRL(var31);
                  } catch (CRLException var9) {
                     var32 = var9;
                     var10001 = false;
                     throw var32;
                  } catch (Exception var10) {
                     var10000 = var10;
                     var10001 = false;
                  }
               } else {
                  label136: {
                     byte[] var38;
                     try {
                        var36 = var31;
                        var38 = new byte[var31.available()];
                     } catch (CRLException var15) {
                        var32 = var15;
                        var10001 = false;
                        throw var32;
                     } catch (Exception var16) {
                        var10000 = var16;
                        var10001 = false;
                        break label136;
                     }

                     byte[] var27 = var38;

                     try {
                        var36.read(var38);
                     } catch (CRLException var13) {
                        var32 = var13;
                        var10001 = false;
                        throw var32;
                     } catch (Exception var14) {
                        var10000 = var14;
                        var10001 = false;
                        break label136;
                     }

                     try {
                        return new X509CRLObjectFX(var27);
                     } catch (CRLException var11) {
                        var32 = var11;
                        var10001 = false;
                        throw var32;
                     } catch (Exception var12) {
                        var10000 = var12;
                        var10001 = false;
                     }
                  }
               }
            }
         }
      }

      Exception var28 = var10000;
      throw new CRLException(var28.toString());
   }

   public Collection engineGenerateCRLs(InputStream inStream) {
      ArrayList var2;
      var2 = new ArrayList.<init>();

      CRL var3;
      while((var3 = this.engineGenerateCRL(inStream)) != null) {
         var2.add(var3);
      }

      return var2;
   }

   public Iterator engineGetCertPathEncodings() {
      return PKIXCertPath.certPathEncodings.iterator();
   }

   public CertPath engineGenerateCertPath(InputStream inStream) {
      return this.engineGenerateCertPath(inStream, "PkiPath");
   }

   public CertPath engineGenerateCertPath(InputStream inStream, String encoding) {
      return new PKIXCertPath(inStream, encoding);
   }

   public CertPath engineGenerateCertPath(List certificates) {
      Iterator var3 = certificates.iterator();

      Object var2;
      do {
         if (!var3.hasNext()) {
            return new PKIXCertPath(certificates);
         }
      } while((var2 = var3.next()) == null || var2 instanceof X509Certificate);

      throw new CertificateException("list contains non X509Certificate object while creating CertPath\n" + var2.toString());
   }
}
